@@ -5,7 +5,7 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="411"/>
+        <location filename="../mainwindow.cpp" line="398"/>
         <source>MX Tools</source>
         <translation type="unfinished"></translation>
     </message>
@@ -32,7 +32,7 @@
     <message>
         <location filename="../mainwindow.ui" line="130"/>
         <source>Close</source>
-        <translation type="unfinished">Sulge</translation>
+        <translation>Sulge</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="137"/>
@@ -45,70 +45,68 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="263"/>
+        <location filename="../mainwindow.ui" line="265"/>
         <source>These MX applications save time and effort with important tasks.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="279"/>
+        <location filename="../mainwindow.ui" line="281"/>
         <source>Hide individual tools from the menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="298"/>
+        <location filename="../mainwindow.ui" line="300"/>
         <source>search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="410"/>
+        <location filename="../mainwindow.cpp" line="397"/>
         <source>About MX Tools</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="411"/>
+        <location filename="../mainwindow.cpp" line="398"/>
         <source>Version: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="413"/>
+        <location filename="../mainwindow.cpp" line="399"/>
         <source>Configuration Tools for MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="414"/>
+        <location filename="../mainwindow.cpp" line="402"/>
         <source>Copyright (c) MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="415"/>
-        <source>License</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="416"/>
-        <source>Changelog</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="417"/>
-        <source>Cancel</source>
-        <translation type="unfinished">Loobu</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="432"/>
-        <source>&amp;Close</source>
+        <location filename="../mainwindow.cpp" line="403"/>
+        <source>%1 License</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>mxtools</name>
+    <name>QObject</name>
     <message>
-        <source>Close</source>
-        <translation type="vanished">Sulge</translation>
+        <location filename="../about.cpp" line="42"/>
+        <source>License</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../about.cpp" line="43"/>
+        <location filename="../about.cpp" line="53"/>
+        <source>Changelog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="44"/>
         <source>Cancel</source>
-        <translation type="vanished">Loobu</translation>
+        <translation>Loobu</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="66"/>
+        <source>&amp;Close</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
